#define BASE8 0x80000000
#define BASE32 0x90000000
#define BASE16 0xa0000000
#define PEEK32(adr) (*(unsigned int *)((adr) + BASE32))
#define POKE32(adr, val) *(unsigned int *)((adr) + BASE32) = (val)
#define PEEK16(adr) (*(unsigned short *)((adr) + BASE16))
#define POKE16(adr, val) *(unsigned short *)((adr) + BASE16) = (val)
#define PEEK8(adr) (*(unsigned char *)((adr) + BASE8))
#define POKE8(adr, val) *(unsigned char *)((adr) + BASE8) = (val)

#define BASE_R 0xa0010000
#define RAM_PEEK16(adr) (*(unsigned short *)((adr) + BASE_R))
#define RAM_POKE16(adr, val) *(unsigned short *)(BASE_R + (adr)) = (val)

#define ID             0x4000
#define CTL            0x4002
#define MUXBUS_CONFIG  0x4004
#define TIMER0         0x4008
#define TIMER1         0x400a
#define FIFO_DAT       0x404c
#define FIFO_STAT      0x404a

#define MUXBUS16       0x8000

#define ADC_CONF       0x4400
#define ADC_MASK       0x4402
#define ADC_DAT(chan)  (0x4402 + 2*(chan))

#define LEDS           0x4012
#define RED_LED        (1<<11)
#define GREEN_LED      (1<<12)

/* If you use the stock tshwctl utility to load this program into the LM32,
 * it assumes the first thing the LM32 does is call ack_startup().  This is
 * used to report the load time.
 */
void ack_startup(void);

/* The shutdown() function will put the LM32 in reset.  It will stay in reset
 * until the ARM host releases reset.
 */
void shutdown(void);

/* Get 32 bit microsecond timer value.
 */
unsigned int get_us(void);

/* This usleep() function does not return until the requested time has
 * elapsed.  It is accurate to within 1 microsecond.
 */
void usleep(unsigned int);

/* This function sends a text string to the console FIFO.
 */
void outstr(char *);

/* This function converts an integer to text and sends it to the FIFO, similar
 * to printf("%d", x)
 */
void outint(unsigned int);

/* This function converts an integer to text and sends it to the FIFO, similar
 * to printf("%x", x)
 */
void outhex(unsigned int);


